package com.ruoyi.web.controller.business;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.business.domain.TbUser;
import com.ruoyi.business.service.ITbUserService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户个人信息Controller
 * 
 * @author xiatao
 * @date 2022-01-18
 */
@Controller
@RequestMapping("/business/apiUser")
public class TbUserController extends BaseController
{
    private String prefix = "business/apiUser";

    @Autowired
    private ITbUserService tbUserService;

    @RequiresPermissions("business:apiUser:view")
    @GetMapping()
    public String apiUser()
    {
        return prefix + "/apiUser";
    }

    /**
     * 查询用户个人信息列表
     */
    @RequiresPermissions("business:apiUser:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TbUser tbUser)
    {
        startPage();
        List<TbUser> list = tbUserService.selectTbUserList(tbUser);
        return getDataTable(list);
    }

    /**
     * 导出用户个人信息列表
     */
    @RequiresPermissions("business:apiUser:export")
    @Log(title = "用户个人信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TbUser tbUser)
    {
        List<TbUser> list = tbUserService.selectTbUserList(tbUser);
        ExcelUtil<TbUser> util = new ExcelUtil<TbUser>(TbUser.class);
        return util.exportExcel(list, "用户个人信息数据");
    }

    /**
     * 新增用户个人信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存用户个人信息
     */
    @RequiresPermissions("business:apiUser:add")
    @Log(title = "用户个人信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(TbUser tbUser)
    {
        return toAjax(tbUserService.insertTbUser(tbUser));
    }

    /**
     * 修改用户个人信息
     */
    @RequiresPermissions("business:apiUser:edit")
    @GetMapping("/edit/{userId}")
    public String edit(@PathVariable("userId") Long userId, ModelMap mmap)
    {
        TbUser tbUser = tbUserService.selectTbUserByUserId(userId);
        mmap.put("tbUser", tbUser);
        return prefix + "/edit";
    }

    /**
     * 修改保存用户个人信息
     */
    @RequiresPermissions("business:apiUser:edit")
    @Log(title = "用户个人信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TbUser tbUser)
    {
        return toAjax(tbUserService.updateTbUser(tbUser));
    }

    /**
     * 删除用户个人信息
     */
    @RequiresPermissions("business:apiUser:remove")
    @Log(title = "用户个人信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tbUserService.deleteTbUserByUserIds(ids));
    }
}
